<?php

/**
 * @file
 * Custom Search API datasource for keeping track of the Sajari id locally.
 */

class SearchApiSajariEntityDataSourceController extends SearchApiEntityDataSourceController {

  protected $table = 'search_api_sajari_item';

  /**
   * {@inheritdoc}
   */
  public function trackItemIndexed(array $item_ids, SearchApiIndex $index) {
    if (!$this->table) {
      return;
    }
    $this->checkIndex($index);

    // We're abusing the keys in $item_ids in our Sajari service to bring back
    // the Sajari ids we need to store in the item index. It couples us to our
    // custom service implementation but it also lets us avoid overriding most
    // of the methods in SearchApiEntityDataSourceController.
    foreach ($item_ids as $sajari_id => $item_id) {
      db_update($this->table)
        ->fields([
          $this->changedColumn => 0,
          'sajari_id' => $sajari_id,
        ])
        ->condition($this->itemIdColumn, $item_id)
        ->condition($this->indexIdColumn, $index->id)
        ->execute();
    }
  }

  /**
   * Gets the Sajari doc id given an item_id.
   *
   * @param int $item_id
   *   The item id for which we want the Sajari doc id.
   * @param \SearchApiIndex $index
   *   The search index the server is querying against.
   *
   * @return string
   *   An empty string or the sajari doc id.
   */
  public function getSajariId($item_id, SearchApiIndex $index) {
    return (string) db_select($this->table, 't')
      ->fields('t', ['sajari_id'])
      ->condition($this->itemIdColumn, $item_id)
      ->condition($this->indexIdColumn, $index->id)
      ->execute()
      ->fetchField();
  }

}
